<h1 align="center">
<img alt="Odoo Bike Shop"
     width="270"
     src="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/logo.png"/>
</h1>

<p align="center">
<a href="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/queue.png">
<img alt="A list of work orders awaiting repair. They are broken down into  various categories such as 'Quotation', 'In Queue', and 'Delayed Awaiting Parts'."
     src="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/queue.png"
     width="360"/>
</a>
<a href="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/bicycles.png">
<img alt="A screen shot showing a list of bicycles including the serial number, make, model, and owner."
     src="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/bicycles.png"
     width="360"/>
</a>
<a href="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/wo_full.png">
<img alt="A screen displaying a customer name and address, a bicycle, and a break down of several parts and services."
     src="https://codeberg.org/atlbikeshed/odoo-bikeshop/raw/branch/main/bikeshop/static/description/work_order.png"
     width="360"/>
</a>
</p>

[![Codeberg CI](https://ci.codeberg.org/api/badges/13359/status.svg)](https://ci.codeberg.org/repos/13359)

This is a plugin for the [Odoo] suite of business management software that
provides workflows for bicycle shops that sell and repair bikes.

It is very early days and this is likely **not** ready for production use. When
it is, it will be available for purchase on the Odoo [app store].


## Translations

Translations can be found in the `i18n/` tree and are licensed separately under
a Creative Commons Attribution-ShareAlike 4.0 International License ([CC BY-SA
4.0]).
To contribute to translations see the project on [Codeberg Translate].


[Odoo]: https://www.odoo.com/
[app store]: https://apps.odoo.com/apps
[CC BY-SA 4.0]: https://creativecommons.org/licenses/by-sa/4.0/
[Codeberg Translate]: https://translate.codeberg.org/projects/odoo-bikeshop/
